| Title: | Access the Legistar Web API |
|---|---|
| Description: | Access public data using the Legistar Web API. |
| Authors: | Eli Pousson [aut, cre, cph] (ORCID: <https://orcid.org/0000-0001-8280-1706>) |
| Maintainer: | Eli Pousson <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.0.0.9000 |
| Built: | 2026-05-27 07:06:00 UTC |
| Source: | https://github.com/elipousson/legistarapi |
legis_get_actions() lists actions and legis_get_action() gets a single
action by ID.
legis_get_actions( ..., client = getOption("legistarapi.client"), simplifyVector = TRUE, error_call = caller_env() ) legis_get_action( id, ..., client = getOption("legistarapi.client"), simplifyVector = TRUE, error_call = caller_env() )legis_get_actions( ..., client = getOption("legistarapi.client"), simplifyVector = TRUE, error_call = caller_env() ) legis_get_action( id, ..., client = getOption("legistarapi.client"), simplifyVector = TRUE, error_call = caller_env() )
... |
Arguments passed on to
|
client |
String with Legistar client name. Defaults to
|
simplifyVector |
Should JSON arrays containing only primitives (i.e. booleans, numbers, and strings) be caused to atomic vectors? |
error_call |
The execution environment of a currently
running function, e.g. |
id |
Action ID. Required for |
legis_get_bodies() lists actions and legis_get_body() gets a single
body by ID.
legis_get_bodies( ..., client = getOption("legistarapi.client"), simplifyVector = TRUE, error_call = caller_env() ) legis_get_body( body_id, ..., client = getOption("legistarapi.client"), simplifyVector = TRUE, error_call = caller_env() )legis_get_bodies( ..., client = getOption("legistarapi.client"), simplifyVector = TRUE, error_call = caller_env() ) legis_get_body( body_id, ..., client = getOption("legistarapi.client"), simplifyVector = TRUE, error_call = caller_env() )
... |
Arguments passed on to
|
client |
String with Legistar client name. Defaults to
|
simplifyVector |
Should JSON arrays containing only primitives (i.e. booleans, numbers, and strings) be caused to atomic vectors? |
error_call |
The execution environment of a currently
running function, e.g. |
body_id |
Body ID. Required for |
Get body types from a Legistar site
legis_get_body_types( ..., client = getOption("legistarapi.client"), simplifyVector = TRUE, error_call = caller_env() ) legis_get_body_type( body_type_id, ..., client = getOption("legistarapi.client"), simplifyVector = TRUE, error_call = caller_env() )legis_get_body_types( ..., client = getOption("legistarapi.client"), simplifyVector = TRUE, error_call = caller_env() ) legis_get_body_type( body_type_id, ..., client = getOption("legistarapi.client"), simplifyVector = TRUE, error_call = caller_env() )
... |
Arguments passed on to
|
client |
String with Legistar client name. Defaults to
|
simplifyVector |
Should JSON arrays containing only primitives (i.e. booleans, numbers, and strings) be caused to atomic vectors? |
error_call |
The execution environment of a currently
running function, e.g. |
body_type_id |
Body type ID. Required for |
Get code sections from a Legistar site
legis_get_code_sections( ..., client = getOption("legistarapi.client"), simplifyVector = TRUE, error_call = caller_env() ) legis_get_code_section( code_section_id, ..., client = getOption("legistarapi.client"), simplifyVector = TRUE, error_call = caller_env() )legis_get_code_sections( ..., client = getOption("legistarapi.client"), simplifyVector = TRUE, error_call = caller_env() ) legis_get_code_section( code_section_id, ..., client = getOption("legistarapi.client"), simplifyVector = TRUE, error_call = caller_env() )
... |
Arguments passed on to
|
client |
String with Legistar client name. Defaults to
|
simplifyVector |
Should JSON arrays containing only primitives (i.e. booleans, numbers, and strings) be caused to atomic vectors? |
error_call |
The execution environment of a currently
running function, e.g. |
code_section_id |
Code section ID. Required for
|
legis_get_event() also requires event_items, agenda_note,
minutes_note, and event_item_attachments parameters. These likely should
be optional so the function should be considered non-functional at present.
legis_get_events( ..., client = getOption("legistarapi.client"), simplifyVector = TRUE, error_call = caller_env() ) legis_get_event( event_id, ..., client = getOption("legistarapi.client"), simplifyVector = TRUE, error_call = caller_env() )legis_get_events( ..., client = getOption("legistarapi.client"), simplifyVector = TRUE, error_call = caller_env() ) legis_get_event( event_id, ..., client = getOption("legistarapi.client"), simplifyVector = TRUE, error_call = caller_env() )
... |
Arguments passed on to
|
client |
String with Legistar client name. Defaults to
|
simplifyVector |
Should JSON arrays containing only primitives (i.e. booleans, numbers, and strings) be caused to atomic vectors? |
error_call |
The execution environment of a currently
running function, e.g. |
event_id |
Event ID. Required for |
Get indexes from a Legistar site
legis_get_indexes( ..., client = getOption("legistarapi.client"), simplifyVector = TRUE, error_call = caller_env() )legis_get_indexes( ..., client = getOption("legistarapi.client"), simplifyVector = TRUE, error_call = caller_env() )
... |
Arguments passed on to
|
client |
String with Legistar client name. Defaults to
|
simplifyVector |
Should JSON arrays containing only primitives (i.e. booleans, numbers, and strings) be caused to atomic vectors? |
error_call |
The execution environment of a currently
running function, e.g. |
Get matter indexes from a Legistar site
legis_get_matter_indexes( ..., client = getOption("legistarapi.client"), simplifyVector = TRUE, error_call = caller_env() )legis_get_matter_indexes( ..., client = getOption("legistarapi.client"), simplifyVector = TRUE, error_call = caller_env() )
... |
Arguments passed on to
|
client |
String with Legistar client name. Defaults to
|
simplifyVector |
Should JSON arrays containing only primitives (i.e. booleans, numbers, and strings) be caused to atomic vectors? |
error_call |
The execution environment of a currently
running function, e.g. |
Get matter requesters from a Legistar site
legis_get_matter_requesters( ..., client = getOption("legistarapi.client"), simplifyVector = TRUE, error_call = caller_env() )legis_get_matter_requesters( ..., client = getOption("legistarapi.client"), simplifyVector = TRUE, error_call = caller_env() )
... |
Arguments passed on to
|
client |
String with Legistar client name. Defaults to
|
simplifyVector |
Should JSON arrays containing only primitives (i.e. booleans, numbers, and strings) be caused to atomic vectors? |
error_call |
The execution environment of a currently
running function, e.g. |
Get matter statuses from a Legistar site
legis_get_matter_statuses( ..., client = getOption("legistarapi.client"), simplifyVector = TRUE, error_call = caller_env() )legis_get_matter_statuses( ..., client = getOption("legistarapi.client"), simplifyVector = TRUE, error_call = caller_env() )
... |
Arguments passed on to
|
client |
String with Legistar client name. Defaults to
|
simplifyVector |
Should JSON arrays containing only primitives (i.e. booleans, numbers, and strings) be caused to atomic vectors? |
error_call |
The execution environment of a currently
running function, e.g. |
Get matter types from a Legistar site
legis_get_matter_types( ..., client = getOption("legistarapi.client"), simplifyVector = TRUE, error_call = caller_env() )legis_get_matter_types( ..., client = getOption("legistarapi.client"), simplifyVector = TRUE, error_call = caller_env() )
... |
Arguments passed on to
|
client |
String with Legistar client name. Defaults to
|
simplifyVector |
Should JSON arrays containing only primitives (i.e. booleans, numbers, and strings) be caused to atomic vectors? |
error_call |
The execution environment of a currently
running function, e.g. |
Get matters from a Legistar site
legis_get_matters( ..., client = getOption("legistarapi.client"), simplifyVector = TRUE, error_call = caller_env() )legis_get_matters( ..., client = getOption("legistarapi.client"), simplifyVector = TRUE, error_call = caller_env() )
... |
Arguments passed on to
|
client |
String with Legistar client name. Defaults to
|
simplifyVector |
Should JSON arrays containing only primitives (i.e. booleans, numbers, and strings) be caused to atomic vectors? |
error_call |
The execution environment of a currently
running function, e.g. |
Get office records from a Legistar site
legis_get_office_records( ..., client = getOption("legistarapi.client"), simplifyVector = TRUE, error_call = caller_env() )legis_get_office_records( ..., client = getOption("legistarapi.client"), simplifyVector = TRUE, error_call = caller_env() )
... |
Arguments passed on to
|
client |
String with Legistar client name. Defaults to
|
simplifyVector |
Should JSON arrays containing only primitives (i.e. booleans, numbers, and strings) be caused to atomic vectors? |
error_call |
The execution environment of a currently
running function, e.g. |
See Adding a New Person for more information on persons in Legistar.
legis_get_persons( ..., client = getOption("legistarapi.client"), simplifyVector = TRUE, error_call = caller_env() ) legis_get_person( person_id, ..., client = getOption("legistarapi.client"), simplifyVector = TRUE, error_call = caller_env() )legis_get_persons( ..., client = getOption("legistarapi.client"), simplifyVector = TRUE, error_call = caller_env() ) legis_get_person( person_id, ..., client = getOption("legistarapi.client"), simplifyVector = TRUE, error_call = caller_env() )
... |
Arguments passed on to
|
client |
String with Legistar client name. Defaults to
|
simplifyVector |
Should JSON arrays containing only primitives (i.e. booleans, numbers, and strings) be caused to atomic vectors? |
error_call |
The execution environment of a currently
running function, e.g. |
person_id |
Person ID. Required for |
Get vote types from a Legistar site
legis_get_vote_types( ..., client = getOption("legistarapi.client"), simplifyVector = TRUE, error_call = caller_env() )legis_get_vote_types( ..., client = getOption("legistarapi.client"), simplifyVector = TRUE, error_call = caller_env() )
... |
Arguments passed on to
|
client |
String with Legistar client name. Defaults to
|
simplifyVector |
Should JSON arrays containing only primitives (i.e. booleans, numbers, and strings) be caused to atomic vectors? |
error_call |
The execution environment of a currently
running function, e.g. |
Review the Legistar Web API documentation for more information. This function is a work in progress. As of May 2024, it returns all results for any query calling itself recursively.
legistar( ..., template = "actions", client = getOption("legistarapi.client"), top = NULL, skip = NULL, select = NULL, filter = NULL, orderby = NULL, direction = NULL, count = NULL, inlinecount = NULL, .multi = "pipe", simplifyVector = TRUE, n_max = NULL, error_call = caller_env() )legistar( ..., template = "actions", client = getOption("legistarapi.client"), top = NULL, skip = NULL, select = NULL, filter = NULL, orderby = NULL, direction = NULL, count = NULL, inlinecount = NULL, .multi = "pipe", simplifyVector = TRUE, n_max = NULL, error_call = caller_env() )
... |
Template variables. |
template |
A template string which consists of a optional HTTP method
and a path containing variables labelled like either |
client |
String with Legistar client name. Defaults to
|
top, skip, select, filter, orderby
|
Passed to internal |
direction |
Default |
count, inlinecount
|
Currently unsupported. |
.multi |
Controls what happens when an element of
If none of these functions work, you can alternatively supply a function that takes a character vector and returns a string. |
simplifyVector |
Should JSON arrays containing only primitives (i.e. booleans, numbers, and strings) be caused to atomic vectors? |
n_max |
Maximum number of records to return. Currently unsupported. |
error_call |
The execution environment of a currently
running function, e.g. |
legistar(template = "persons", client = "seattle", top = 5) legistar(template = "bodies", client = "baltimore", top = 5)legistar(template = "persons", client = "seattle", top = 5) legistar(template = "bodies", client = "baltimore", top = 5)
A data frame of identified Legistar client sites tested to check if client
responded to an API request with legis_get_bodies(). Last updated
2024-05-12.
legistar_clientslegistar_clients
A data frame with 286 rows and 2 variables:
clientClient string
apilogical If TRUE, client returned an API response
A data frame with reference information from the Legistar Web API documentation: https://webapi.legistar.com/. Organized in a Google Sheet for use with this package: https://docs.google.com/spreadsheets/d/1Py-Oqyb8kW13x0_BjGJS-fw1EdZzqBeIsjxvQvBV5dM/edit?usp=sharing Last updated 2024-05-12.
legistar_methodslegistar_methods
A data frame with 124 rows and 8 variables:
typeAPI method type
methodHTTP Request Method
templateTemplate string
urlHelp URL
descriptionAPI method description
responseExpected API method response
modelNameCorresponding modelName for response
nmSnake case method name
https://webapi.legistar.com/